## Description

<!-- Brief summary of the changes. -->

## Checklist

- [ ] Tests pass (`pytest`)
- [ ] Lint passes (`ruff check src/ tests/`)
- [ ] Types pass (`mypy src/`)
- [ ] Self-scan passes (`heckler --ci .`)

## Related issues

Closes #
